# Python
from __future__ import unicode_literals

__all__ = ['handler400', 'handler403', 'handler404', 'handler500']


handler400 = 'site_utils.views.handle_400'
handler403 = 'site_utils.views.handle_403'
handler404 = 'site_utils.views.handle_404'
handler500 = 'site_utils.views.handle_500'



# Python
from __future__ import unicode_literals

# Django
from django.core.management.base import BaseCommand

# Django-Site-Utils
from ...notify import notify_users
from ...utils import auth_is_installed


class Command(BaseCommand):
    """
    Management command to notify site admins/managers.
    """

    help = 'Send a notification message to site admins/managers.'

    def add_arguments(self, parser):
        parser.add_argument(
            'subject_text',
            nargs='?',
            metavar='subject',
        )
        parser.add_argument(
            'body_text',
            nargs='*',
            metavar='body',
        )
        parser.add_argument(
            '-a',
            '--admins',
            action='store_true',
            dest='admins',
            default=False,
            help='Notify all addresses in settings.ADMINS.',
        )
        parser.add_argument(
            '-m',
            '--managers',
            action='store_true',
            dest='managers',
            default=False,
            help='Notify all addresses in settings.MANAGERS.',
        )
        if auth_is_installed():
            parser.add_argument(
                '-u',
                '--superusers',
                action='store_true',
                dest='superusers',
                default=False,
                help='Notify all active users with is_superuser status.',
            )
            parser.add_argument(
                '-s',
                '--staff',
                action='store_true',
                dest='staff',
                default=False,
                help='Notify all active users with is_staff status.',
            )
            parser.add_argument(
                '--all',
                action='store_true',
                dest='all_users',
                default=False,
                help='Notify all admins, managers, superusers and staff.',
            )
        else:
            parser.add_argument(
                '--all',
                action='store_true',
                dest='all_users',
                default=False,
                help='Notify all admins and managers.',
            )
        # TODO: Implement below.
        # parser.add_argument('--separate', action='store_true',
        #                     dest='separate', default=False, help='Send a separate notification to each recipient.')
        parser.add_argument(
            '--bcc',
            action='store_true',
            dest='bcc',
            default=False,
            help='BCC all recipients.',
        )
        parser.add_argument(
            '--subject-template',
            dest='subject_template',
            default=None,
            help='Override subject template for this notification.',
        )
        parser.add_argument(
            '--body-template',
            dest='body_template',
            default=None,
            help='Override body template for this notification.',
        )
        parser.add_argument(
            '-n',
            '--dry-run',
            action='store_true',
            dest='dry_run',
            default=False,
            help='Dry run; only show the email that would be sent.',
        )

    def handle(self, *args, **options):
        notify_users(**options)



# Python
from __future__ import unicode_literals

# Django
from django.apps import apps
from django.contrib.contenttypes.models import ContentType
from django.db import connection


def cleanup_stale_content_types(**options):
    """
    Remove state content types.
    """
    command = options.get('_command', None)
    verbosity = int(options.get('verbosity', 1))
    dry_run = bool(options.get('dry_run', False))
    if apps.is_installed('django.contrib.contenttypes'):
        for content_type in ContentType.objects.all():
            if content_type.model_class():
                continue
            if verbosity >= 1 and command:
                command.stdout.write('Removing {!r}\n'.format(content_type))
            if not dry_run:
                content_type.delete()


def cleanup_unused_database_tables(**options):
    """
    Remove unused database tables.
    """
    command = options.get('_command', None)
    verbosity = int(options.get('verbosity', 1))
    dry_run = bool(options.get('dry_run', False))
    cursor = connection.cursor()
    all_tables = set(connection.introspection.table_names())
    django_tables = set(connection.introspection.django_table_names())
    for stale_table in (all_tables - django_tables):
        sql = 'DROP TABLE %s;' % stale_table
        if verbosity >= 1 and command:
            command.stdout.write('Removing table {}\n'.format(stale_table))
        if verbosity >= 2:
            command.stdout.write('{}\n'.format(sql))
        if not dry_run:
            cursor.execute(sql)



# Python
from __future__ import unicode_literals

# Django
from django.conf import settings
from django.utils.translation import gettext_lazy as _


DEFAULT_SITE_CLEANUP_FUNCTIONS = (
    'site_utils.cleanup.cleanup_stale_content_types',
    'site_utils.cleanup.cleanup_unused_database_tables',
)

DEFAULT_SITE_NOTIFY_DEFAULT_RECIPIENTS = ('admins',)

DEFAULT_SITE_NOTIFY_SUBJECT_TEMPLATE = 'site_utils/notify_subject.txt'

DEFAULT_SITE_NOTIFY_BODY_TEMPLATE = 'site_utils/notify_body.txt'

DEFAULT_SITE_UPDATE_COMMANDS = {
    'default': [
        'check',
        ('migrate', [], {'fake_initial': True}),
        ('collectstatic', [], {}, 'staticfiles'),
    ],
}

DEFAULT_SITE_ERROR_MESSAGES = {
    400: (
        _('Bad Request'),
        _('The request could not be understood by the server.'),
    ),
    403: (
        _('Forbidden'),
        _('You do not have permission to access the requested resource.'),
    ),
    404: (
        _('Not Found'),
        _('The requested page could not be found.'),
    ),
    500: (
        _('Server Error'),
        _('An internal server error has occurred.'),
    ),
    502: (
        _('Bad Gateway'),
        _('An invalid response was received from the upstream server.'),
    ),
    503: (
        _('Server Unavailable'),
        _('The server is currently unavailable.'),
    ),
    504: (
        _('Gateway Timeout'),
        _('Did not receive a timely response from the upstream server.'),
    ),
}

DEFAULT_SITE_ERROR_TEMPLATES = [
    (r'', 'site_utils/error.html'),
]


def get_site_utils_setting(name, merge_dicts=False):
    try:
        default_setting = globals()['DEFAULT_{}'.format(name)]
        setting = getattr(settings, name, None)
        if merge_dicts:
            setting_dict = dict(default_setting.items())
            if setting:
                setting_dict.update(setting.items())
            return setting_dict
        else:
            return setting or default_setting
    except KeyError:
        raise RuntimeError('invalid setting name: {}'.format(name))



# Python
from __future__ import unicode_literals
import json
from collections import OrderedDict

# Django
from django.contrib.sites.models import Site
from django.core.management.base import BaseCommand, CommandError

# Django-Site-Utils
from ...utils import app_is_installed


class Command(BaseCommand):

    help = 'View or modify the current/selected Site.'

    def add_arguments(self, parser):
        parser.add_argument(
            '-n',
            '--name',
            action='store',
            dest='name',
            default=None,
            help='Update the site name.',
        )
        parser.add_argument(
            '-d',
            '--domain',
            action='store',
            dest='domain',
            default=None,
            help='Update the site domain.',
        )
        parser.add_argument(
            '--id',
            action='store',
            dest='site_id',
            type=int,
            default=0,
            help='Specify an alternate site ID to view/modify.',
        )
        parser.add_argument(
            '--create',
            action='store_true',
            dest='create',
            default=False,
            help='Create a new site if needed.',
        )
        parser.add_argument(
            '--all',
            action='store_true',
            dest='all_sites',
            default=False,
            help='View/modify all sites.',
        )
        parser.add_argument(
            '--json',
            action='store_true',
            dest='output_json',
            default=False,
            help='Output site details as JSON.',
        )

    def handle(self, *args, **options):
        verbosity = int(options.get('verbosity', 1))
        name = options.get('name', None) or options.get('_name', None)
        domain = options.get('domain', None)
        site_id = options.get('site_id', None)
        create = options.get('create', False)
        all_sites = options.get('all_sites', False)
        output_json = options.get('output_json', False)
        if not app_is_installed('django.contrib.sites'):
            raise CommandError('Sites app is not installed')
        try:
            if all_sites:
                sites = Site.objects.order_by('pk')
            elif site_id:
                sites = [Site.objects.get(pk=site_id)]
            else:
                sites = [Site.objects.get_current()]
        except Site.DoesNotExist:
            if create:
                create_kwargs = dict(id=site_id, name=name, domain=domain)
                create_kwargs = dict((k, v) for k, v in create_kwargs if v is not None)
                sites = [Site.objects.create(**create_kwargs)]
                if verbosity >= 2:
                    self.stderr.write('Created site: {}'.format(sites[0]))
            elif site_id:
                raise CommandError('Site with id={} not found'.format(site_id))
            else:
                raise CommandError('Current site not found')
        sites_data = []
        for site in sites:
            update_fields = []
            if name:
                site.name = name
                update_fields.append('name')
            if domain:
                site.domain = domain
                update_fields.append('domain')
            if update_fields:
                site.save(update_fields=update_fields)
                if verbosity >= 2:
                    self.stderr.write('Updated site: {} ({})'.format(site, ' & '.join(update_fields)))
            site_data = OrderedDict([
                ('id', site.pk),
                ('name', site.name),
                ('domain', site.domain),
            ])
            sites_data.append(site_data)
        if output_json:
            if all_sites:
                self.stdout.write('{}\n'.format(json.dumps(sites_data, indent=4)))
            else:
                self.stdout.write('{}\n'.format(json.dumps(sites_data[0], indent=4)))
        elif verbosity >= 1:
            for site_data in sites_data:
                self.stdout.write('ID={id} Name="{name}" Domain="{domain}"\n'.format(**site_data))



# Python
from __future__ import unicode_literals
import re

# Django
from django.shortcuts import render
from django.template import Context
from django.template.context import RequestContext
from django.utils.translation import gettext_lazy as _

# Django-Site-Utils
from .settings import get_site_utils_setting


def handle_error(request, status, title=None, message=None, exception=None, template_name=None):
    error_messages = get_site_utils_setting('SITE_ERROR_MESSAGES', merge_dicts=True)
    if not template_name:
        error_templates = get_site_utils_setting('SITE_ERROR_TEMPLATES')
        template_name = 'site_utils/error.html'
        for regex, template in error_templates:
            if re.match(regex, request.path.lstrip('/')):
                template_name = template or template_name
                break
    if title is None:
        title = error_messages.get(status, (_('Unknown Error'),))[0]
    if message is None:
        message = error_messages.get(status, (None, _('An unknown error occurred')))[1]
    error_context = {
        'error_title': title,
        'error_message': message,
        'error_status': status,
        'exception': exception,
    }
    try:
        context = RequestContext(request, error_context)
    except Exception:
        raise  # FIXME: Which exception is raised?
        context = Context(error_context)
    response = render(request, template_name, context.flatten())
    response.status_code = status
    return response


def handle_400(request, exception=None, template_name=None):
    return handle_error(request, 400, exception=exception, template_name=template_name)


def handle_403(request, exception=None, template_name=None):
    return handle_error(request, 403, exception=exception, template_name=template_name)


def handle_404(request, exception=None, template_name=None):
    return handle_error(request, 404, exception=exception, template_name=template_name)


def handle_500(request, template_name=None):
    return handle_error(request, 500, template_name=template_name)



# Python
import socket

# Django
from django.conf import settings as django_settings


def hostname(request):
    return {
        'hostname': socket.gethostname(),
    }


def settings(request):
    return {
        'settings': django_settings,
    }



# Python
from __future__ import unicode_literals
import collections

# Django
from django.conf import settings
from django.contrib.auth import get_user_model
from django.core.mail import EmailMessage
from django.template.loader import render_to_string
from django.test.client import RequestFactory
from django.utils.encoding import force_text

# Django-Site-Utils
from .settings import get_site_utils_setting
from .utils import auth_is_installed

__all__ = ['notify_users']


def notify_users(subject_text=None, body_text=None, all_users=False,
                 admins=False, managers=False, superusers=False, staff=False,
                 bcc=False, subject_template=None, body_template=None,
                 dry_run=False, request=None, **kwargs):
    """
    Send an email notification to selected site users.
    """
    # Determine which user types should be notified.
    admins = admins or all_users
    managers = managers or all_users
    if auth_is_installed():
        superusers = superusers or all_users
        staff = staff or all_users
        user_model = get_user_model()
    else:
        superusers = False
        staff = False
        user_model = None
    if not (admins or managers or superusers or staff):
        default_recipients = set(get_site_utils_setting('SITE_NOTIFY_DEFAULT_RECIPIENTS'))
        admins = 'admins' in default_recipients
        managers = 'managers' in default_recipients
        if auth_is_installed():
            superusers = 'superusers' in default_recipients
            staff = 'staff' in default_recipients

    # Build full list of recipients.
    recipients = collections.OrderedDict()
    if admins:
        for name, email in settings.ADMINS:
            recipients.setdefault(email, name)
    if managers:
        for name, email in settings.MANAGERS:
            recipients.setdefault(email, name)
    if superusers and user_model:
        for user in user_model.objects.filter(is_active=True, is_superuser=True):
            recipients.setdefault(user.email, user.get_full_name() or user.email)
    if staff and user_model:
        for user in user_model.objects.filter(is_active=True, is_staff=True):
            recipients.setdefault(user.email, user.get_full_name() or user.email)

    # Render subject and body of notification.
    # TODO: Future feature: render subject/body per recipient.
    subject_template = subject_template or get_site_utils_setting('SITE_NOTIFY_SUBJECT_TEMPLATE')
    body_template = body_template or get_site_utils_setting('SITE_NOTIFY_BODY_TEMPLATE')
    subject_text = subject_text if subject_text is not None else 'Site Notification'
    if isinstance(body_text, (list, tuple)):
        body_text = '\n\n'.join(body_text)
    context = dict(subject=subject_text, body=body_text)
    request = request or RequestFactory().get('/')
    subject = render_to_string(subject_template, context, request)
    subject = ' '.join(filter(None, map(lambda x: x.strip(), subject.splitlines())))
    subject = settings.EMAIL_SUBJECT_PREFIX + subject
    body = render_to_string(body_template, context, request)

    # Create and send the email.
    email_kwargs = dict(subject=subject, body=body)
    # FIXME: Sanitize user full name and email?
    email_recipients = ['"{}" <{}>'.format(v, k) for k, v in recipients.items()]
    email_kwargs['bcc' if bcc else 'to'] = email_recipients
    email_message = EmailMessage(**email_kwargs)
    if dry_run:
        print(force_text(email_message.message()))
    else:
        email_message.send()



# Python
from __future__ import unicode_literals

# Django
from django.apps import apps

__all__ = ['app_is_installed', 'auth_is_installed']


def app_is_installed(app_label):
    """
    Determine whether the given app is currently installed, either by short name
    or full dotted import name.
    """
    for app_config in apps.get_app_configs():
        if app_label in (app_config.name, app_config.label):
            return True
    return False


def auth_is_installed():
    """
    Return whether django.contrib.auth is installed.
    """
    return app_is_installed('django.contrib.auth')



# Python
from __future__ import unicode_literals

# Django
from django.core.management.base import BaseCommand
from django.utils.module_loading import import_string

# Django-Site-Utils
from ...settings import get_site_utils_setting


class Command(BaseCommand):

    help = 'Run site cleanup functions.'

    def add_arguments(self, parser):
        parser.add_argument(
            '--noinput',
            '--no-input',
            action='store_false',
            dest='interactive',
            default=True,
            help='Tells Django to NOT prompt the user for input of any kind.',
        )
        parser.add_argument(
            '-n',
            '--dry-run',
            action='store_true',
            dest='dry_run',
            default=False,
            help='Dry run; only show what changes would be made.',
        )

    def handle(self, *args, **options):
        options['_command'] = self
        verbosity = int(options.get('verbosity', 1))
        site_cleanup_functions = []
        for func_import in get_site_utils_setting('SITE_CLEANUP_FUNCTIONS'):
            site_cleanup_functions.append(import_string(func_import))
        # FIXME: Honor interactive option and prompt before each function.
        for func in site_cleanup_functions:
            if verbosity >= 2:
                self.stdout.write('Running site cleanup function "{}"'.format(func.__name__))
            func(**options)



# Django
try:
    from django.urls import re_path
except ImportError:
    from django.conf.urls import url as re_path
from django.utils.module_loading import import_string

# Django-Site-Utils
from .handlers import handler400, handler403, handler404, handler500


urlpatterns = [
    re_path(r'^400.html$', import_string(handler400), name='bad-request'),
    re_path(r'^403.html$', import_string(handler403), name='forbidden'),
    re_path(r'^404.html$', import_string(handler404), name='not-found'),
    re_path(r'^500.html$', import_string(handler500), name='server-error'),
]



# Python
from __future__ import unicode_literals
import os

# Six
import six

# Django
from django.conf import settings
from django.core.management.base import BaseCommand
from django.core.management import get_commands, load_command_class, call_command, CommandError

# Django-Site-Utils
from ...utils import app_is_installed
from ...settings import get_site_utils_setting


class Command(BaseCommand):

    help = 'Execute multiple management commands.'
    requires_system_checks = False

    def add_arguments(self, parser):
        parser.add_argument(
            '--noinput',
            '--no-input',
            action='store_false',
            dest='interactive',
            default=True,
            help='Tells Django to NOT prompt the user for input of any kind.',
        )
        parser.add_argument(
            '--list-groups',
            action='store_true',
            dest='list_groups',
            default=False,
            help='Output available groups for site update commands.',
        )
        parser.add_argument(
            'group',
            nargs='*',
            help='Specific group of update commands to run.',
        )

    @staticmethod
    def _get_command_instance(name):
        app_name = get_commands()[name]
        if isinstance(app_name, BaseCommand):
            return app_name
        else:
            return load_command_class(app_name, name)

    @staticmethod
    def _parse_cmd_specs(cmd_specs):
        parsed_cmd_specs = []
        for cmd_spec in cmd_specs:
            if isinstance(cmd_spec, six.string_types):
                cmd_opts = [cmd_spec, (), {}, None]
            elif isinstance(cmd_spec, (list, tuple)):
                cmd_opts = (list(cmd_spec) + [None, None, None, None])[:4]
                if not cmd_opts[0]:
                    raise CommandError('no command')
                cmd_opts[1] = cmd_opts[1] or ()
                cmd_opts[2] = cmd_opts[2] or {}
                if isinstance(cmd_opts[3], six.string_types):
                    cmd_opts[3] = [cmd_opts[3]]
            else:
                raise CommandError('unknown command spec')
            parsed_cmd_specs.append(cmd_opts)
        return parsed_cmd_specs

    def handle(self, *args, **options):
        verbosity = int(options.get('verbosity', 1))
        interactive = bool(options.get('interactive', True))
        list_groups = bool(options.get('list_groups', False))
        groups = options.get('group', None) or []
        site_update_commands = get_site_utils_setting('SITE_UPDATE_COMMANDS', merge_dicts=True)

        if not groups:
            if list_groups:
                groups = site_update_commands.keys()
            elif 'default' in site_update_commands:
                groups = ['default']
        for group in groups:
            if group not in site_update_commands:
                raise CommandError('Unknown group %s' % group)

        for group in groups:
            if verbosity >= 1 and list_groups:
                msg = '[{}]'.format(group)
                self.stdout.write(self.style.MIGRATE_HEADING(msg))
            elif verbosity >= 1 and not list_groups:
                msg = 'site_update: Running commands from group "{}".'.format(group)
                self.stdout.write(self.style.MIGRATE_HEADING('=' * len(msg.strip())))
                self.stdout.write(self.style.MIGRATE_HEADING(msg))
                self.stdout.write(self.style.MIGRATE_HEADING('=' * len(msg.strip())))
            cmd_specs = self._parse_cmd_specs(site_update_commands[group])
            for cmd_spec in cmd_specs:
                cmd_name = cmd_spec[0]
                cmd_args = cmd_spec[1]
                cmd_opts = cmd_spec[2]
                cmd_display_args = ['{!r}'.format(a) for a in cmd_args]
                cmd_display_args.extend(['{}={!r}'.format(k, v) for k, v in cmd_opts.items()])
                cmd_apps = cmd_spec[3] or []
                cmd_apps_missing = []
                for cmd_app in cmd_apps:
                    if not app_is_installed(cmd_app):
                        cmd_apps_missing.append(cmd_app)
                if list_groups:
                    if cmd_apps_missing:
                        cmd_skipped = ' (skipped: {} not installed)'.format(', '.join(cmd_apps_missing))
                    else:
                        cmd_skipped = ''
                    if verbosity >= 2:
                        msg = '{}({}){}'.format(cmd_name, ', '.join(cmd_display_args), cmd_skipped)
                        self.stdout.write(self.style.MIGRATE_LABEL(msg))
                else:
                    if cmd_apps_missing:
                        if verbosity >= 2:
                            msg = '\nsite_update: Skipping: {} ({} not installed).'.format(cmd_name, ', '.join(cmd_apps_missing))
                            self.stdout.write(self.style.WARNING(msg))
                        continue
                    if verbosity >= 1:
                        msg = '\nsite_update: Running {}({})'.format(cmd_name, ', '.join(cmd_display_args))
                        self.stdout.write(self.style.MIGRATE_LABEL(msg))
                        self.stdout.write(self.style.MIGRATE_LABEL('-' * len(msg.strip())))

                    # Check if command supports an "interactive" argument.
                    try:
                        cmd_instance = self._get_command_instance(cmd_name)
                    except KeyError:
                        raise CommandError('Unknown command: {!r}'.format(cmd_name))
                    cmd_parser = cmd_instance.create_parser('', cmd_name)
                    if bool('interactive' in [opt.dest for opt in cmd_parser._actions]):
                        cmd_opts.setdefault('interactive', interactive)
                    cmd_opts.setdefault('verbosity', verbosity)

                    # Prevent collectstatic from failing when the clear option is
                    # specified and the static root doesn't exist.
                    if cmd_name == 'collectstatic' and cmd_opts.get('clear', False):
                        if not os.path.exists(settings.STATIC_ROOT):
                            os.makedirs(settings.STATIC_ROOT)
                    call_command(cmd_name, *cmd_args, **cmd_opts)



# Python
from __future__ import unicode_literals
import os

# Django
from django.core.management.base import BaseCommand, CommandError
from django.test import override_settings
from django.test.client import RequestFactory

# BeautifulSoup
try:
    import bs4
except ImportError:
    bs4 = None

# LXML
try:
    import lxml
except ImportError:
    lxml = None

# Html5Lib
try:
    import html5lib
except ImportError:
    html5lib = None

# Django-Site-Utils
from ...views import handle_error


class Command(BaseCommand):

    help = 'Generate static error pages.'

    def add_arguments(self, parser):
        parser.add_argument(
            'status',
            nargs='+',
            type=int,
            help='HTTP status code(s) of error pages to generate.',
        )
        parser.add_argument(
            '--dest',
            default='.',
            help='Destination directory for generated pages.',
        )
        parser.add_argument(
            '--prefix',
            default='',
            help='Prefix for generated filenames.',
        )
        parser.add_argument(
            '--suffix',
            default='.html',
            help='Suffix for generated filenames.',
        )
        parser.add_argument(
            '--url',
            default='/',
            help='URL prefix to determine which template to use.',
        )
        parser.add_argument(
            '--no-clean-html',
            action='store_false',
            dest='clean_html',
            default=True,
            help='Disable cleaning tags from the generated HTML.',
        )
        # TODO: Add arguments to select which HTML tags to clean.

    @staticmethod
    def _clean_error_html(html):
        if lxml is not None:
            parser = 'lxml'
        elif html5lib is not None:
            parser = 'html5lib'
        else:
            parser = 'html.parser'
        bs = bs4.BeautifulSoup(html, parser)
        # Remove script tags.
        for tag in bs.findAll('script'):
            tag.extract()
        # Remove comments except IE conditionals
        for tag in bs.findAll(text=lambda text: isinstance(text, bs4.Comment)):
            if '[if' not in tag.string:
                tag.extract()
        # Replace relative links.
        for tag in bs.findAll('a', attrs={'href': True}):
            if tag['href'].startswith('/'):
                tag['href'] = '#'
        return bs.prettify()

    def handle(self, *args, **options):
        verbosity = int(options.get('verbosity', 1))
        statuses = options.get('status')
        dest_path = os.path.abspath(options.get('dest', '.'))
        prefix = options.get('prefix', '')
        suffix = options.get('suffix', '.html')
        url = options.get('url', '/')
        clean_html = options.get('clean_html', True)
        if clean_html and not bs4:
            raise CommandError('BeautifulSoup4 is required to clean the generated HTML. Specify --no-clean-html to disable this feature.')
        for status in statuses:
            with override_settings(ALLOWED_HOSTS=['testserver']):
                request = RequestFactory().get(url)
                response = handle_error(request, status)
            html = response.content
            if clean_html:
                html = self._clean_error_html(html)
            dest_file = os.path.join(dest_path, '{}{}{}'.format(prefix, status, suffix))
            if os.path.exists(dest_file):
                with open(dest_file, 'r') as df:
                    old_html = df.read()
                if html == old_html:
                    if verbosity >= 2:
                        self.stdout.write('No change to {} error for {} in {}.\n'.format(status, url, dest_file))
                    continue
            if not os.path.exists(dest_path):
                os.makedirs(dest_path)
            with open(dest_file, 'w') as df:
                df.write(html)
            if verbosity >= 1:
                self.stdout.write('Rendered HTML for {} error for {} to {}.\n'.format(status, url, dest_file))



# Python
from __future__ import unicode_literals

# Django
from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _


class SiteUtilsConfig(AppConfig):

    name = 'site_utils'
    verbose_name = _('Site Utilities')
